@@ -1,8 +1,8 @@
 #' @importFrom utils globalVariables
-utils::globalVariables(c('doubleFactorials',
-                         'logDoubleFactorials',
-                         'log2DoubleFactorials'),
-                       'TreeTools')
+utils::globalVariables(c("doubleFactorials",
+                         "logDoubleFactorials",
+                         "log2DoubleFactorials"),
+                       "TreeTools")
 
 #' Double factorial
 #'
